@@ -23,7 +23,7 @@ class X_API:
 
     def callback_task(
             self,
-            task_id: str
+            task_id: str,
             post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("POST", f"pretrain/task/{task_id}/callback", json=post_data).json()
